@@ -296,17 +296,15 @@ clearlooks_draw_button (cairo_t *cr,
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
 
-	if (params->xthickness == 3 || params->ythickness == 3)
+	if (params->xthickness >= 3 && params->ythickness >= 3)
 	{
-		if (params->xthickness == 3)
-			xoffset = 1;
-		if (params->ythickness == 3)
-			yoffset = 1;
+		xoffset = 1;
+		yoffset = 1;
 	}
 
 	radius = MIN (radius, MIN ((width - 2.0 - xoffset * 2.0) / 2.0, (height - 2.0 - yoffset * 2) / 2.0));
 
-	if (params->xthickness == 3 || params->ythickness == 3)
+	if (params->xthickness >= 3 && params->ythickness >= 3)
 	{
 		params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width, height, radius+1, params->corners);
 	}
@@ -413,32 +411,51 @@ static void
 clearlooks_draw_entry (cairo_t *cr,
                        const ClearlooksColors *colors,
                        const WidgetParameters *params,
+                       const FocusParameters  *focus,
                        int x, int y, int width, int height)
 {
 	const CairoColor *base = &colors->base[params->state_type];
 	CairoColor border = colors->shade[params->disabled ? 3 : 6];
 	double radius = MIN (params->radius, MIN ((width - 4.0) / 2.0, (height - 4.0) / 2.0));
+	int xoffset, yoffset;
 
 	if (params->focus)
-		border = colors->spot[2];
+		border = focus->color;
 
 	cairo_save (cr);
 
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
 
+	if (params->xthickness >= 3 && params->ythickness >= 3)
+	{
+		params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width, height, radius+1, params->corners);
+		xoffset = 1;
+		yoffset = 1;
+	}
+	else
+	{
+		xoffset = 0;
+		yoffset = 0;
+	}
+
 	/* Now fill the area we want to be base[NORMAL]. */
-	ge_cairo_rounded_rectangle (cr, 2, 2, width-4, height-4, MAX(0, radius-1), params->corners);
+	ge_cairo_rounded_rectangle (cr, xoffset + 1, yoffset + 1, width - (xoffset + 1)*2,
+	                            height - (yoffset + 1) * 2, MAX(0, radius-1),
+	                            params->corners);
 	ge_cairo_set_color (cr, base);
 	cairo_fill (cr);
 
-	params->style_functions->draw_inset (cr, &params->parentbg, 0, 0, width, height, radius+1, params->corners);
-
 	/* Draw the inner shadow */
 	if (params->focus)
 	{
-		ge_cairo_set_color (cr, &colors->spot[0]);
-		ge_cairo_inner_rounded_rectangle (cr, 2, 2, width-4, height-4, MAX(0, radius-1), params->corners);
+		CairoColor focus_shadow;
+		ge_shade_color (&border, 1.61, &focus_shadow);
+		
+		clearlooks_set_mixed_color (cr, base, &focus_shadow, 0.5);
+		ge_cairo_inner_rounded_rectangle (cr, xoffset + 1, yoffset + 1,
+		                                  width - (xoffset + 1)*2, height - (yoffset + 1)*2,
+		                                  MAX(0, radius-1), params->corners);
 		cairo_stroke (cr);
 	}
 	else
@@ -450,12 +467,15 @@ clearlooks_draw_entry (cairo_t *cr,
 
 		cairo_set_line_cap (cr, CAIRO_LINE_CAP_BUTT);
 		cairo_move_to (cr, 2.5, height-radius);
-		cairo_arc (cr, 2.5+MAX(0, radius-1), 2.5+MAX(0, radius-1), MAX(0, radius-1), G_PI, 270*(G_PI/180));
+		cairo_arc (cr, xoffset + 1.5 + MAX(0, radius-1), yoffset + 1.5 + MAX(0, radius-1),
+		           MAX(0, radius-1), G_PI, 270*(G_PI/180));
 		cairo_line_to (cr, width-radius, 2.5);
 		cairo_stroke (cr);
 	}
 
-	ge_cairo_inner_rounded_rectangle (cr, 1, 1, width-2, height-2, radius, params->corners);
+	ge_cairo_inner_rounded_rectangle (cr, xoffset, yoffset,
+	                                  width-2*xoffset, height-2*yoffset,
+	                                  radius, params->corners);
 	if (params->focus || params->disabled)
 		ge_cairo_set_color (cr, &border);
 	else
@@ -465,6 +485,79 @@ clearlooks_draw_entry (cairo_t *cr,
 	cairo_restore (cr);
 }
 
+static void
+clearlooks_draw_entry_progress (cairo_t *cr,
+                                const ClearlooksColors *colors,
+                                const WidgetParameters *params,
+                                const EntryProgressParameters *progress,
+                                int x, int y, int width, int height)
+{
+	CairoColor border;
+	CairoColor fill;
+	gint entry_width, entry_height;
+	double entry_radius;
+	double radius;
+
+	cairo_save (cr);
+
+	fill = colors->bg[params->state_type];
+	ge_shade_color (&fill, 0.9, &border);
+
+	if (progress->max_size_known)
+	{
+		entry_width = progress->max_size.width + progress->border.left + progress->border.right;
+		entry_height = progress->max_size.height + progress->border.top + progress->border.bottom;
+		entry_radius = MIN (params->radius, MIN ((entry_width - 4.0) / 2.0, (entry_height - 4.0) / 2.0));
+	}
+	else
+	{
+		entry_radius = params->radius;
+	}
+
+	radius = MAX (0, entry_radius + 1.0 - MAX (MAX (progress->border.left, progress->border.right),
+	                                           MAX (progress->border.top, progress->border.bottom)));
+
+	if (progress->max_size_known)
+	{
+		/* Clip to the max size, and then draw a (larger) rectangle ... */
+		ge_cairo_rounded_rectangle (cr, progress->max_size.x,
+		                                progress->max_size.y,
+		                                progress->max_size.width,
+		                                progress->max_size.height,
+		                                radius,
+		                                CR_CORNER_ALL);
+		cairo_clip (cr);
+
+		/* We just draw wider by one pixel ... */
+		ge_cairo_set_color (cr, &fill);
+		cairo_rectangle (cr, x, y + 1, width, height - 2);
+		cairo_fill (cr);
+
+		cairo_set_line_width (cr, 1.0);
+		ge_cairo_set_color (cr, &border);
+		ge_cairo_inner_rectangle (cr, x - 1, y, width + 2, height);
+		cairo_stroke (cr);
+	}
+	else
+	{
+		ge_cairo_rounded_rectangle (cr, x, y, width + 10, height + 10, radius, CR_CORNER_ALL);
+		cairo_clip (cr);
+		ge_cairo_rounded_rectangle (cr, x - 10, y - 10, width + 10, height + 10, radius, CR_CORNER_ALL);
+		cairo_clip (cr);
+
+		ge_cairo_set_color (cr, &fill);
+		ge_cairo_rounded_rectangle (cr, x + 1, y + 1, width - 2, height - 2, radius, CR_CORNER_ALL);
+		cairo_fill (cr);
+
+		cairo_set_line_width (cr, 1.0);
+		ge_cairo_set_color (cr, &border);
+		ge_cairo_rounded_rectangle (cr, x + 0.5, y + 0.5, width - 1.0, height - 1.0, radius, CR_CORNER_ALL);
+		cairo_stroke (cr);
+	}
+
+	cairo_restore (cr);
+}
+
 static void
 clearlooks_draw_spinbutton (cairo_t *cr,
                             const ClearlooksColors *colors,
@@ -843,7 +936,7 @@ clearlooks_draw_progressbar_fill (cairo_t *cr,
 	cairo_paint (cr);
 
 	/* Draw the Strokes */
-	while (tile_pos <= width+x_step)
+	while (stroke_width > 0 && tile_pos <= width+x_step)
 	{
 		cairo_move_to (cr, stroke_width/2-x_step, 0);
 		cairo_line_to (cr, stroke_width-x_step,   0);
@@ -1212,7 +1305,7 @@ clearlooks_draw_tab (cairo_t *cr,
 	/* And calculate the strip size too, while you're at it */
 	if (tab->gap_side == CL_GAP_TOP || tab->gap_side == CL_GAP_BOTTOM)
 	{
-		height += 3.0;
+		height += 2.0;
 		length = height;
 		stripe_fill_size = (tab->gap_side == CL_GAP_TOP ? stripe_size/height : stripe_size/(height-2));
 
@@ -1662,17 +1755,37 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 
 	if (scrollbar->horizontal)
 	{
-		if (stepper->stepper == CL_STEPPER_A)
+		if (stepper->stepper == CL_STEPPER_START)
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
-		else if (stepper->stepper == CL_STEPPER_D)
+		else if (stepper->stepper == CL_STEPPER_END)
 			corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_START_INNER)
+		{
+			x -= 1;
+			width += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_END_INNER)
+		{
+			width += 1;
+		}
 	}
 	else
 	{
-		if (stepper->stepper == CL_STEPPER_A)
+		if (stepper->stepper == CL_STEPPER_START)
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
-		else if (stepper->stepper == CL_STEPPER_D)
+		else if (stepper->stepper == CL_STEPPER_END)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_START_INNER)
+		{
+			y -= 1;
+			height += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_END_INNER)
+		{
+			height += 1;
+		}
 	}
 
 	cairo_translate (cr, x, y);
@@ -2175,7 +2288,7 @@ clearlooks_draw_checkbox (cairo_t *cr,
 	cairo_translate (cr, x, y);
 	cairo_set_line_width (cr, 1);
 
-	if (widget->xthickness > 2 && widget->ythickness > 2)
+	if (widget->xthickness >= 3 && widget->ythickness >= 3)
 	{
 		widget->style_functions->draw_inset (cr, &widget->parentbg, 0, 0, width, height, 1, CR_CORNER_ALL);
 
@@ -2378,6 +2491,18 @@ clearlooks_draw_focus (cairo_t *cr,
 	cairo_stroke (cr);
 }
 
+void
+clearlooks_set_mixed_color (cairo_t          *cr,
+                            const CairoColor *color1,
+                            const CairoColor *color2,
+                            gdouble mix_factor)
+{
+	CairoColor composite;
+
+	ge_mix_color (color1, color2, mix_factor, &composite);
+	ge_cairo_set_color (cr, &composite);
+}
+
 void
 clearlooks_register_style_classic (ClearlooksStyleFunctions *functions, ClearlooksStyleConstants *constants)
 {
@@ -2390,6 +2515,7 @@ clearlooks_register_style_classic (ClearlooksStyleFunctions *functions, Clearloo
 	functions->draw_progressbar_fill    = clearlooks_draw_progressbar_fill;
 	functions->draw_slider_button       = clearlooks_draw_slider_button;
 	functions->draw_entry               = clearlooks_draw_entry;
+	functions->draw_entry_progress      = clearlooks_draw_entry_progress;
 	functions->draw_spinbutton          = clearlooks_draw_spinbutton;
 	functions->draw_spinbutton_down     = clearlooks_draw_spinbutton_down;
 	functions->draw_optionmenu          = clearlooks_draw_optionmenu;
@@ -2414,7 +2540,7 @@ clearlooks_register_style_classic (ClearlooksStyleFunctions *functions, Clearloo
 	functions->draw_handle              = clearlooks_draw_handle;
 	functions->draw_resize_grip         = clearlooks_draw_resize_grip;
 	functions->draw_arrow               = clearlooks_draw_arrow;
-	functions->draw_focus                = clearlooks_draw_focus;
+	functions->draw_focus               = clearlooks_draw_focus;
 	functions->draw_checkbox            = clearlooks_draw_checkbox;
 	functions->draw_radiobutton         = clearlooks_draw_radiobutton;
 	functions->draw_shadow              = clearlooks_draw_shadow;
