@@ -1,24 +1,32 @@
-/* Redmond theme engine
+/* Redmond95 - a cairo based GTK+ engine
  * Copyright (C) 2001 Red Hat, Inc.
+ * Copyright (C) 2006 Andrew Johnson <acjgenius@earthlink.net>
+ * Copyright (C) 2006-2007 Benjamin Berg <benjamin@sipsolutions.net>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
  *
  * Written by Owen Taylor <otaylor@redhat.com>
  * modified by Andrew Johnson <ajgenius@ajgenius.us>
- */ 
+ * modified by Benjamin Berg <benjamin@sipsolutions.net>
+ *
+ */
+
+
 #include "redmond_gtk2_engine.h"
 #include "redmond_gtk2_drawing.h"
 #include "redmond_gtk2_misc.h"
@@ -434,7 +442,7 @@ redmond_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
       GdkModifierType pointer_mask;
       GList *children = NULL, *child = NULL;
      
-      gdk_window_get_pointer(widget->window, &pointer_x, &pointer_y, &pointer_mask);
+      gdk_window_get_pointer(gtk_widget_get_window (widget), &pointer_x, &pointer_y, &pointer_mask);
 	    
       if (GE_IS_CONTAINER(widget))
         {
@@ -443,14 +451,17 @@ redmond_gtk2_engine_hack_menu_shell_motion(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_WIDGET(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
-	          if ((pointer_x >= GTK_WIDGET(child->data)->allocation.x) && 
-	              (pointer_y >= GTK_WIDGET(child->data)->allocation.y) &&
-	              (pointer_x < (GTK_WIDGET(child->data)->allocation.x + 
-	                              GTK_WIDGET(child->data)->allocation.width)) && 
-	              (pointer_y < (GTK_WIDGET(child->data)->allocation.y +
-	                              GTK_WIDGET(child->data)->allocation.height)))
+	          GtkAllocation allocation;
+	          gtk_widget_get_allocation (GTK_WIDGET(child->data), &allocation);
+
+	          if ((pointer_x >= allocation.x) && 
+	              (pointer_y >= allocation.y) &&
+	              (pointer_x < (allocation.x + 
+	                              allocation.width)) && 
+	              (pointer_y < (allocation.y +
+	                              allocation.height)))
 	            {
                       gtk_widget_set_state (GTK_WIDGET(child->data), GTK_STATE_PRELIGHT);
 	            }
@@ -491,13 +502,12 @@ redmond_gtk2_engine_hack_menu_shell_leave(GtkWidget *widget,
           for (child = g_list_first(children); child; child = g_list_next(child))
             {
 	      if ((child->data) && GE_IS_MENU_ITEM(child->data) && 
-                  (GTK_WIDGET_STATE(GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
+                  (gtk_widget_get_state (GTK_WIDGET(child->data)) != GTK_STATE_INSENSITIVE))
 	        {
-                  if ((!GE_IS_MENU(GTK_MENU_ITEM(child->data)->submenu)) || 
-                      (!(GTK_WIDGET_REALIZED(GTK_MENU_ITEM(child->data)->submenu) && 
-                         GTK_WIDGET_VISIBLE(GTK_MENU_ITEM(child->data)->submenu) &&
-                         GTK_WIDGET_REALIZED(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel) &&
-                         GTK_WIDGET_VISIBLE(GTK_MENU(GTK_MENU_ITEM(child->data)->submenu)->toplevel))))
+	          GtkWidget *submenu = gtk_menu_item_get_submenu (GTK_MENU_ITEM(child->data));
+                  if ((!GE_IS_MENU(submenu)) || 
+                      (!(gtk_widget_get_realized(submenu) && 
+                         gtk_widget_get_visible (submenu))))
 	          {
                     gtk_widget_set_state (GTK_WIDGET(child->data), GTK_STATE_NORMAL);
                   }
@@ -528,25 +538,25 @@ redmond_gtk2_engine_hack_menu_shell_setup_signals(GtkWidget *widget)
       if (!g_object_get_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_HACK_SET"))
       {
         id = g_signal_connect(G_OBJECT(widget), "motion-notify-event",
-                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_motion,
+                                             (GCallback)redmond_gtk2_engine_hack_menu_shell_motion,
                                              NULL);
                                   
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_MOTION_ID", (gpointer)id);
         
         id = g_signal_connect(G_OBJECT(widget), "leave-notify-event",
-                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_leave,
+                                             (GCallback)redmond_gtk2_engine_hack_menu_shell_leave,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_LEAVE_ID", (gpointer)id);
                                              
         id = g_signal_connect(G_OBJECT(widget), "destroy-event",
-                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_destroy,
+                                             (GCallback)redmond_gtk2_engine_hack_menu_shell_destroy,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_DESTROY_ID", (gpointer)id);
  
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_HACK_SET", (gpointer)1);
         
         id = g_signal_connect(G_OBJECT(widget), "style-set",
-                                             (GtkSignalFunc)redmond_gtk2_engine_hack_menu_shell_style_set,
+                                             (GCallback)redmond_gtk2_engine_hack_menu_shell_style_set,
                                              NULL);
         g_object_set_data(G_OBJECT(widget), "REDMOND_MENU_SHELL_STYLE_SET_ID", (gpointer)id);
       }
