@@ -35,9 +35,6 @@ typedef enum {
 	WIDGET_PROGRESS_BAR,
 	WIDGET_MENUBAR,
 	WIDGET_MENUBAR_ITEM,
-#ifndef GTK_DISABLE_DEPRECATED
-	WIDGET_OPTION_MENU,
-#endif /* GTK_DISABLE_DEPRECATED */
 	WIDGET_TOOLBAR,
 	WIDGET_DEFAULT_BUTTON
 } WidgetType;
@@ -62,9 +59,6 @@ widget_type_get_type (void)
 			{ WIDGET_PROGRESS_BAR, "WIDGET_PROGRESS_BAR", "GtkProgessBar" },
 			{ WIDGET_MENUBAR, "WIDGET_MENUBAR", "GtkMenubar" },
 			{ WIDGET_MENUBAR_ITEM, "WIDGET_MENUBAR_ITEM", "GtkMenubar-item" },
-#ifndef GTK_DISABLE_DEPRECATED
-			{ WIDGET_OPTION_MENU, "WIDGET_OPTION_MENU", "GtkOptionMenu" },
-#endif
 			{ WIDGET_TOOLBAR, "WIDGET_TOOLBAR", "GtkToolbar" },
 			{ WIDGET_DEFAULT_BUTTON, "WIDGET_DEFAULT_BUTTON", "GtkButton-has-default" },
 			{ 0, NULL, NULL }
@@ -383,34 +377,6 @@ static Test tests[] = {
 		GTK_EXPANDER_EXPANDED,
 		GDK_WINDOW_EDGE_SOUTH
 	},
-#ifndef GTK_DISABLE_DEPRECATED
-	{
-		FUNCTION_BOX,
-		WIDGET_OPTION_MENU,
-		"NULL:optionmenu",
-		STATE_ALL,
-		SHADOW_ALL,
-		GTK_ARROW_UP,
-		TRUE,
-		GTK_POS_TOP,
-		GTK_ORIENTATION_HORIZONTAL,
-		GTK_EXPANDER_EXPANDED,
-		GDK_WINDOW_EDGE_SOUTH
-	},
-	{
-		FUNCTION_BOX,
-		WIDGET_OPTION_MENU,
-		"NULL:optionmenu",
-		STATE_ALL,
-		SHADOW_ALL,
-		GTK_ARROW_UP,
-		TRUE,
-		GTK_POS_TOP,
-		GTK_ORIENTATION_HORIZONTAL,
-		GTK_EXPANDER_EXPANDED,
-		GDK_WINDOW_EDGE_SOUTH
-	},
-#endif /* GTK_DISABLE_DEPRECATED */
 	{
 		FUNCTION_BOX,
 		WIDGET_TOOLBAR,
@@ -545,12 +511,12 @@ end:
 static void
 run_functions (Test *test)
 {
-	GtkStyle *style = window->style;
-	GdkWindow *mywindow = window->window;
+	GtkStyle *style = gtk_widget_get_style (window);
+	GdkWindow *mywindow = gtk_widget_get_window (window);
 	
 	if (widgets[test->widget]) {
-		style = widgets[test->widget]->style;
-		mywindow = widgets[test->widget]->window;
+		style = gtk_widget_get_style (widgets[test->widget]);
+		mywindow = gtk_widget_get_window (widgets[test->widget]);
 	}
 	
 	if (test->function & FUNCTION_ARROW)
@@ -648,8 +614,7 @@ create_testwidgets ()
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (store));
 
 	widgets[WIDGET_TREE_VIEW] = treeview;
-	/* lets abuse the private API ... */
-	widgets[WIDGET_TREE_VIEW_HEADER] = gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), 0)->button;
+	widgets[WIDGET_TREE_VIEW_HEADER] = gtk_widget_get_parent (gtk_widget_get_parent (gtk_tree_view_column_get_widget (gtk_tree_view_get_column (GTK_TREE_VIEW (treeview), 0))));
 	
 	
 	widgets[WIDGET_SCALE] = gtk_hscale_new_with_range (0, 1, 0.1);
@@ -657,16 +622,12 @@ create_testwidgets ()
 	widgets[WIDGET_MENUBAR] = gtk_menu_bar_new ();
 	widgets[WIDGET_MENUBAR_ITEM] = gtk_menu_item_new_with_label ("blah");
 	gtk_menu_shell_append (GTK_MENU_SHELL (widgets[WIDGET_MENUBAR]), widgets[WIDGET_MENUBAR_ITEM]);
-#ifndef GTK_DISABLE_DEPRECATED
-	widgets[WIDGET_OPTION_MENU] = gtk_option_menu_new ();
-#else
-#warning Not testing engines against GtkOptionMenu
-#endif /* GTK_DISABLE_DEPRECATED */
 	widgets[WIDGET_TOOLBAR] = gtk_toolbar_new ();
 	widgets[WIDGET_DEFAULT_BUTTON] = gtk_button_new_with_label ("blah");
 	/* nasty but *shrug* */
-	GTK_WIDGET_SET_FLAGS(widgets[WIDGET_DEFAULT_BUTTON], GTK_CAN_DEFAULT);
-	GTK_WIDGET_SET_FLAGS(widgets[WIDGET_DEFAULT_BUTTON], GTK_HAS_DEFAULT);
+	gtk_widget_set_can_default (widgets[WIDGET_DEFAULT_BUTTON], TRUE);
+	/* XXX: How to do this without the API? Is it even possible? */
+	/*gtk_widget_set_has_default (widgets[WIDGET_DEFAULT_BUTTON], TRUE);*/
 }
 
 int
@@ -689,7 +650,7 @@ main (int argc, char **argv)
 	gtk_container_add ((GtkContainer*)window, box);
 	
 	for (i = 0; i < WIDGET_COUNT; i++) {
-		if (widgets[i] && !widgets[i]->parent)
+		if (widgets[i] && !gtk_widget_get_parent (widgets[i]))
 			gtk_box_pack_end (GTK_BOX (box), widgets[i], FALSE, FALSE, 0);
 	}
 
